==> qtjambi-qt3drender-6.2.2-sources.jar: io/qt/qt3d/render/QAbstractTextureImage.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates the necessary information to create an OpenGL texture image</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html">Qt3DRender::QAbstractTextureImage</a></p>
 */
public abstract class QAbstractTextureImage extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractTextureImage.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QAbstractTextureImage {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        protected io.qt.qt3d.render.QTextureImageDataGenerator dataGenerator(){
            return dataGenerator_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.qt3d.render.QTextureImageDataGenerator dataGenerator_native_constfct(long __this__nativeId);
        
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#face-prop">Qt3DRender::QAbstractTextureImage::faceChanged(Qt3DRender::QAbstractTexture::CubeMapFace)</a></p>
     */
    @io.qt.QtPropertyNotify(name="face")
    public final Signal1<io.qt.qt3d.render.QAbstractTexture.CubeMapFace> faceChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#layer-prop">Qt3DRender::QAbstractTextureImage::layerChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="layer")
    public final Signal1<@io.qt.QtPrimitiveType Integer> layerChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#mipLevel-prop">Qt3DRender::QAbstractTextureImage::mipLevelChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="mipLevel")
    public final Signal1<@io.qt.QtPrimitiveType Integer> mipLevelChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAbstractTextureImage(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAbstractTextureImage() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#QAbstractTextureImage">Qt3DRender::QAbstractTextureImage::QAbstractTextureImage(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QAbstractTextureImage(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAbstractTextureImage instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#face-prop">Qt3DRender::QAbstractTextureImage::face()const</a></p>
     */
    @io.qt.QtPropertyReader(name="face")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAbstractTexture.CubeMapFace face(){
        return io.qt.qt3d.render.QAbstractTexture.CubeMapFace.resolve(face_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int face_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#layer-prop">Qt3DRender::QAbstractTextureImage::layer()const</a></p>
     */
    @io.qt.QtPropertyReader(name="layer")
    @io.qt.QtUninvokable
    public final int layer(){
        return layer_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int layer_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#mipLevel-prop">Qt3DRender::QAbstractTextureImage::mipLevel()const</a></p>
     */
    @io.qt.QtPropertyReader(name="mipLevel")
    @io.qt.QtUninvokable
    public final int mipLevel(){
        return mipLevel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int mipLevel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#notifyDataGeneratorChanged">Qt3DRender::QAbstractTextureImage::notifyDataGeneratorChanged()</a></p>
     */
    @io.qt.QtUninvokable
    protected final void notifyDataGeneratorChanged(){
        notifyDataGeneratorChanged_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void notifyDataGeneratorChanged_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#setFace">Qt3DRender::QAbstractTextureImage::setFace(Qt3DRender::QAbstractTexture::CubeMapFace)</a></p>
     */
    @io.qt.QtPropertyWriter(name="face")
    public final void setFace(io.qt.qt3d.render.QAbstractTexture.CubeMapFace face){
        setFace_native_Qt3DRender_QAbstractTexture_CubeMapFace(QtJambi_LibraryUtilities.internal.nativeId(this), face.value());
    }
    
    private native void setFace_native_Qt3DRender_QAbstractTexture_CubeMapFace(long __this__nativeId, int face);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#setLayer">Qt3DRender::QAbstractTextureImage::setLayer(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="layer")
    public final void setLayer(int layer){
        setLayer_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), layer);
    }
    
    private native void setLayer_native_int(long __this__nativeId, int layer);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#setMipLevel">Qt3DRender::QAbstractTextureImage::setMipLevel(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="mipLevel")
    public final void setMipLevel(int level){
        setMipLevel_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), level);
    }
    
    private native void setMipLevel_native_int(long __this__nativeId, int level);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#dataGenerator">Qt3DRender::QAbstractTextureImage::dataGenerator()const</a></p>
     */
    @io.qt.QtUninvokable
    protected abstract io.qt.qt3d.render.QTextureImageDataGenerator dataGenerator();
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QTextureImageDataGenerator dataGenerator_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractTextureImage(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAbstractTextureImage(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAbstractTextureImage instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.1-sources.jar: io/qt/qt3d/render/QAbstractTextureImage.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulates the necessary information to create an OpenGL texture image</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html">Qt3DRender::QAbstractTextureImage</a></p>
 */
public abstract class QAbstractTextureImage extends io.qt.qt3d.core.QNode
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractTextureImage.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QAbstractTextureImage {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        protected io.qt.qt3d.render.QTextureImageDataGenerator dataGenerator(){
            return dataGenerator_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.qt3d.render.QTextureImageDataGenerator dataGenerator_native_constfct(long __this__nativeId);
        
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#face-prop">Qt3DRender::QAbstractTextureImage::faceChanged(Qt3DRender::QAbstractTexture::CubeMapFace)</a></p>
     */
    @io.qt.QtPropertyNotify(name="face")
    public final Signal1<io.qt.qt3d.render.QAbstractTexture.CubeMapFace> faceChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#layer-prop">Qt3DRender::QAbstractTextureImage::layerChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="layer")
    public final Signal1<@io.qt.QtPrimitiveType Integer> layerChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#mipLevel-prop">Qt3DRender::QAbstractTextureImage::mipLevelChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="mipLevel")
    public final Signal1<@io.qt.QtPrimitiveType Integer> mipLevelChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QAbstractTextureImage(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAbstractTextureImage() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#QAbstractTextureImage">Qt3DRender::QAbstractTextureImage::QAbstractTextureImage(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QAbstractTextureImage(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAbstractTextureImage instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#face-prop">Qt3DRender::QAbstractTextureImage::face()const</a></p>
     */
    @io.qt.QtPropertyReader(name="face")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAbstractTexture.CubeMapFace face(){
        return io.qt.qt3d.render.QAbstractTexture.CubeMapFace.resolve(face_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int face_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#layer-prop">Qt3DRender::QAbstractTextureImage::layer()const</a></p>
     */
    @io.qt.QtPropertyReader(name="layer")
    @io.qt.QtUninvokable
    public final int layer(){
        return layer_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int layer_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#mipLevel-prop">Qt3DRender::QAbstractTextureImage::mipLevel()const</a></p>
     */
    @io.qt.QtPropertyReader(name="mipLevel")
    @io.qt.QtUninvokable
    public final int mipLevel(){
        return mipLevel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int mipLevel_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#notifyDataGeneratorChanged">Qt3DRender::QAbstractTextureImage::notifyDataGeneratorChanged()</a></p>
     */
    @io.qt.QtUninvokable
    protected final void notifyDataGeneratorChanged(){
        notifyDataGeneratorChanged_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void notifyDataGeneratorChanged_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#setFace">Qt3DRender::QAbstractTextureImage::setFace(Qt3DRender::QAbstractTexture::CubeMapFace)</a></p>
     */
    @io.qt.QtPropertyWriter(name="face")
    public final void setFace(io.qt.qt3d.render.QAbstractTexture.CubeMapFace face){
        setFace_native_Qt3DRender_QAbstractTexture_CubeMapFace(QtJambi_LibraryUtilities.internal.nativeId(this), face.value());
    }
    
    private native void setFace_native_Qt3DRender_QAbstractTexture_CubeMapFace(long __this__nativeId, int face);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#setLayer">Qt3DRender::QAbstractTextureImage::setLayer(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="layer")
    public final void setLayer(int layer){
        setLayer_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), layer);
    }
    
    private native void setLayer_native_int(long __this__nativeId, int layer);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#setMipLevel">Qt3DRender::QAbstractTextureImage::setMipLevel(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="mipLevel")
    public final void setMipLevel(int level){
        setMipLevel_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), level);
    }
    
    private native void setMipLevel_native_int(long __this__nativeId, int level);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qabstracttextureimage.html#dataGenerator">Qt3DRender::QAbstractTextureImage::dataGenerator()const</a></p>
     */
    @io.qt.QtUninvokable
    protected abstract io.qt.qt3d.render.QTextureImageDataGenerator dataGenerator();
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QTextureImageDataGenerator dataGenerator_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractTextureImage(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAbstractTextureImage(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAbstractTextureImage instance, QDeclarativeConstructor constructor);
    
}
